Juan Lang : wintrust: Copy time to verify from cert info.

Alexandre Julliard julliard at winehq.org
Thu Oct 4 06:21:03 CDT 2007


Module: wine
Branch: master
Commit: 85efd02fab2440686a812a7c6d58f339259113ec
URL:    http://source.winehq.org/git/wine.git/?a=commit;h=85efd02fab2440686a812a7c6d58f339259113ec

Author: Juan Lang <juan.lang at gmail.com>
Date:   Wed Oct  3 11:54:18 2007 -0700

wintrust: Copy time to verify from cert info.

---

 dlls/wintrust/softpub.c |   14 +++++++++++++-
 1 files changed, 13 insertions(+), 1 deletions(-)

diff --git a/dlls/wintrust/softpub.c b/dlls/wintrust/softpub.c
index 5a2aab5..f1aae3b 100644
--- a/dlls/wintrust/softpub.c
+++ b/dlls/wintrust/softpub.c
@@ -276,7 +276,19 @@ HRESULT WINAPI SoftpubLoadMessage(CRYPT_PROVIDER_DATA *data)
                 CRYPT_PROVIDER_SGNR signer = { sizeof(signer), { 0 } };
                 DWORD i;
 
-                /* Add empty signer, so we can add a cert to it */
+                /* Add a signer with nothing but the time to verify, so we can
+                 * add a cert to it
+                 */
+                if (data->pWintrustData->u.pCert->psftVerifyAsOf)
+                    memcpy(&data->sftSystemTime, &signer.sftVerifyAsOf,
+                     sizeof(FILETIME));
+                else
+                {
+                    SYSTEMTIME sysTime;
+
+                    GetSystemTime(&sysTime);
+                    SystemTimeToFileTime(&sysTime, &signer.sftVerifyAsOf);
+                }
                 ret = data->psPfns->pfnAddSgnr2Chain(data, FALSE, 0, &signer);
                 if (!ret)
                     goto error;




More information about the wine-cvs mailing list